==> rheolef_5.93.orig.tar.gz: rheolef-5.93/nfem/tst/form_generic_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}

RHEOLEF_BASIS_PATH=${RHEOLEF_BASIS_PATH-"../basis"}
RHEOLEF_NUMBERING_PATH=${RHEOLEF_NUMBERING_PATH-"../basis"}
RHEOLEF_FORM_ELEMENT_PATH=${RHEOLEF_FORM_ELEMENT_PATH-"../form_element"}
export RHEOLEF_BASIS_PATH
export RHEOLEF_NUMBERING_PATH
export RHEOLEF_FORM_ELEMENT_PATH

FORMS="2D_D div_div"
APPROXS="P1 P2"

status=0
command="../bin/mkgeo_grid_2d 10 10 > square.geo"
echo "      $command"
eval $command 2>/dev/null


for form in $FORMS; do
  for approx in $APPROXS; do
     command="./form_generic_tst square -approx $approx -form $form"
     echo "      $command"
     eval $command >/dev/null 2>/dev/null
     if test $? -ne 0; then status=1; echo "        => *NO*"; fi
  done
done

command="/bin/rm -f square.geo"
echo "      $command"
eval $command
exit $status

==> rheolef_6.6.orig.tar.gz: rheolef-6.6/nfem/tst/form_generic_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}

RHEOLEF_BASIS_PATH=${RHEOLEF_BASIS_PATH-"../basis"}
RHEOLEF_NUMBERING_PATH=${RHEOLEF_NUMBERING_PATH-"../basis"}
RHEOLEF_FORM_ELEMENT_PATH=${RHEOLEF_FORM_ELEMENT_PATH-"../form_element"}
export RHEOLEF_BASIS_PATH
export RHEOLEF_NUMBERING_PATH
export RHEOLEF_FORM_ELEMENT_PATH

FORMS="2D_D div_div"
APPROXS="P1 P2"

status=0
command="../sbin/mkgeo_grid_2d 10 10 > square.geo"
echo "      $command"
eval $command 2>/dev/null


for form in $FORMS; do
  for approx in $APPROXS; do
     command="./form_generic_tst square -approx $approx -form $form"
     echo "      $command"
     eval $command >/dev/null 2>/dev/null
     if test $? -ne 0; then status=1; echo "        => *NO*"; fi
  done
done

command="/bin/rm -f square.geo"
echo "      $command"
eval $command
exit $status
